@@ -3,16 +3,16 @@
  * Copyright 2008 The gstreamermm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -20,8 +20,10 @@
 #ifndef _GSTREAMERMM_MINIOBJECT_H
 #define _GSTREAMERMM_MINIOBJECT_H
 
-#include <glibmm/objectbase.h>
 #include <gst/gstminiobject.h>
+#include <glibmm/refptr.h>
+#include <glibmm/value.h>
+#include <gstreamermm/wrap.h>
 
 namespace Gst
 {
@@ -31,7 +33,7 @@ class MiniObject_Class;
 /** This is a base class for some gstreamermm objects.
  * It is similar to Glib::Object but has no GObject property or signal support.
  */
-class MiniObject : public Glib::ObjectBase
+class MiniObject
 {
 public:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -41,37 +43,30 @@ public:
   typedef GstMiniObjectClass BaseClassType;
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
-//protected:
-public:
-  //friend Glib::wrap;
+private:
+  friend class MiniObject_Class;
+  static CppClassType mini_object_class_;
 
+  // noncopyable
+  MiniObject(const MiniObject&);
+  MiniObject& operator=(const MiniObject&);
+
+protected:
   MiniObject();
-  MiniObject(GstMiniObject* castitem, bool take_copy = false);
-
-public:
+  explicit MiniObject(GstMiniObject* castitem, bool take_copy = false);
   virtual ~MiniObject();
   
+public:
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
+  static GType get_type()      G_GNUC_CONST;
+  static GType get_base_type() G_GNUC_CONST;
+#endif
+
+public:
   //Note that we don't add a constructor for gst_mini_object_new()
   //because it's just an equivalent for g_object_new(), 
   //which is just an equivalent for C++'s new(). 
 
-//protected:
-  // noncopyable
-  /** A copy constructor.  Please note that copying is actually only supported
-   * in sub-classes that define their own custom copy function in the C API
-   * such as Gst::Event, Gst::Buffer, etc. otherwise the copy is not
-   * successful and a warning is issued.
-   */
-  MiniObject(const MiniObject&);
-
-  /** Assignment operator.  Please note that copying is actually only
-   * supported in sub-classes that define their own custom copy function in
-   * the C API such as Gst::Event, Gst::Buffer, etc. otherwise the copy
-   * is not successful and a warning is issued.
-   */
-  MiniObject& operator=(const MiniObject&);
-
-public:
   /** Returns the entire set of flags for the mini-object.
    * @return The Gst::MiniObject flags.
    */
@@ -93,20 +88,6 @@ public:
    */
   void unset_flag(guint flag);
 
-  /** Creates a copy of the mini-object.  Please note that copying is
-   * supported only by sub-classes of Gst::MiniObject such as Gst::Event,
-   * Gst::Buffer, etc. that define their own custom copy function in the C API
-   * and not directly by Gst::MiniObject, a base class.  If used from only a
-   * Gst::MiniObject instance and not a sub-class instance the copy is not
-   * successful and a warning is issued.
-   *
-   * MT safe.
-   *
-   * @return A copy of the mini-object or warn if this object is only a
-   * Gst::MiniObject and not a sub-class that defines its own copy function.
-   */
-  Glib::RefPtr<Gst::MiniObject> copy() const;
-
   /** Checks if a mini-object is writable. A mini-object is writable if the
    * reference count is one and the Gst::MINI_OBJECT_FLAG_READONLY flag is not
    * set. Modification of a mini-object should only be done after verifying
@@ -137,6 +118,8 @@ public:
   ///Provides access to the underlying C GstMiniObject.
   const GstMiniObject* gobj() const { return reinterpret_cast<GstMiniObject*>(gobject_); }
 
+  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
+  GstMiniObject* gobj_copy();
 
   // static void replace(Glib::RefPtr<Gst::MiniObject> & olddata, Glib::RefPtr<Gst::MiniObject> & newdata);
 
@@ -144,21 +127,36 @@ protected:
   void swap(MiniObject& other);
 
 protected:
-  GstMiniObject* gobject_; //TODO: Doesn't this shadow a member variable in Glib::ObjectBase?
+  GstMiniObject* gobject_;
 };
 
 } // namespace Gst
 
-/*
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 namespace Glib
 {
-  inline Glib::RefPtr<Gst::MiniObject> wrap(GstMiniObject *object, bool take_copy)
+
+template <>
+class Value< Glib::RefPtr<Gst::MiniObject> > : public ValueBase
+{
+public:
+  static GType value_type()
   {
-    return Glib::RefPtr<Gst::MiniObject>(new MiniObject(object, take_copy));
+    return Gst::MiniObject::get_type();
   }
 
-} //namespace Glib
-*/
+  void set(const Glib::RefPtr<Gst::MiniObject>& object)
+  {
+    g_value_set_pointer(&gobject_, Gst::unwrap(object));
+  }
 
-#endif //#ifndef _GSTREAMERMM_MINIOBJECT_H
+  Glib::RefPtr<Gst::MiniObject> get()
+  {
+    return Glib::RefPtr<Gst::MiniObject>(Gst::wrap_auto(static_cast<GstMiniObject*>(g_value_get_pointer(&gobject_)), true));
+  }
+};
 
+} // namespace Glib
+#endif // #ifndef DOXYGEN_SHOULD_SKIP_THIS
+
+#endif // #ifndef _GSTREAMERMM_MINIOBJECT_H
